@@ -17,6 +17,7 @@ var keys_8h =
     [ "PW_KEY_AUDIO_CHANNELS", "keys_8h.html#a7f63a5688e90b4d78e8db0c7a18bd959", null ],
     [ "PW_KEY_AUDIO_FORMAT", "keys_8h.html#a0b13a2631ffb67076f67105d1ca347d6", null ],
     [ "PW_KEY_AUDIO_RATE", "keys_8h.html#af4643e961de004488943e2ab0322ac4c", null ],
+    [ "PW_KEY_CLIENT_ACCESS", "keys_8h.html#a550a0954601e7bf139955115f4b1c030", null ],
     [ "PW_KEY_CLIENT_API", "keys_8h.html#ad38809401a347afdefdefc12b9066e10", null ],
     [ "PW_KEY_CLIENT_ID", "keys_8h.html#a40cda23f85c981d1fc72e452f0972c0b", null ],
     [ "PW_KEY_CLIENT_NAME", "keys_8h.html#a53bbec2813b8e4f108d1d50596e0669b", null ],
@@ -67,8 +68,11 @@ var keys_8h =
     [ "PW_KEY_MEDIA_ARTIST", "keys_8h.html#a5239e21cdcdd48b4dc147305df1cb742", null ],
     [ "PW_KEY_MEDIA_CATEGORY", "keys_8h.html#ad58dc457d6b068c7ae086b6792824404", null ],
     [ "PW_KEY_MEDIA_CLASS", "keys_8h.html#aed255c860a65813289cb4c4620243da6", null ],
+    [ "PW_KEY_MEDIA_COMMENT", "keys_8h.html#ae0e0edc267b24e27054f72f899cb2123", null ],
     [ "PW_KEY_MEDIA_COPYRIGHT", "keys_8h.html#a377a7240f82837f1c861976faf4240af", null ],
+    [ "PW_KEY_MEDIA_DATE", "keys_8h.html#a920ad1d3f16b5fe42e001aab2af08680", null ],
     [ "PW_KEY_MEDIA_FILENAME", "keys_8h.html#a0823daaf814cb12aca70c024f76eaf0b", null ],
+    [ "PW_KEY_MEDIA_FORMAT", "keys_8h.html#a5fcd76f87ed122633f0a90ac05aae123", null ],
     [ "PW_KEY_MEDIA_ICON", "keys_8h.html#a49cb5fe34980f268f7bb844f54de72f5", null ],
     [ "PW_KEY_MEDIA_ICON_NAME", "keys_8h.html#ad7fe1ca68b65df33c09b8d14cfd708b0", null ],
     [ "PW_KEY_MEDIA_LANGUAGE", "keys_8h.html#a308a6720f63b611d74666c4dfc6dbe7d", null ],
@@ -119,6 +123,7 @@ var keys_8h =
     [ "PW_KEY_SEC_LABEL", "keys_8h.html#a9cde0fd069af370dd80ad3deac5ee053", null ],
     [ "PW_KEY_SEC_PID", "keys_8h.html#a3273f4c970bf0c85f1eb220d368ea444", null ],
     [ "PW_KEY_SEC_UID", "keys_8h.html#ad6000734888b498669ad7aebcee155eb", null ],
+    [ "PW_KEY_STREAM_CAPTURE_SINK", "keys_8h.html#a1ac41df86c2b03ef693864d48d80f735", null ],
     [ "PW_KEY_STREAM_DONT_REMIX", "keys_8h.html#a79843e403121d8dda275d869c770d3f2", null ],
     [ "PW_KEY_STREAM_IS_LIVE", "keys_8h.html#afc94345e17e428e4816adf8eb0bcb993", null ],
     [ "PW_KEY_STREAM_LATENCY_MAX", "keys_8h.html#a2d0601eb11704dc85da950b5188a4ad3", null ],
