@@ -104,11 +104,11 @@ var NAVTREEINDEX =
 "core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
 "global_8h.html#a3c30e6a36a12ab02e97c7a0014d578d0",
 "impl-node_8c.html#a0c09f345941b97bd6bc796ee014214f0",
-"link_8h.html#a481b4d0b9cd49478fd13dc8934478840",
-"pages.html",
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b",
-"structpw__device__info.html#accce9f7bcbbb1e5142298f18ce03d799",
-"structpw__properties.html#aef040055887634f636bb26594091c31c"
+"link_8h.html#a0f2b028863c04de464bc9f84fa8a00aa",
+"page_thread_loop.html",
+"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91",
+"structpw__device__events.html#a01a060fea8c0b9d8ccd4eb2aff2848e6",
+"structpw__properties.html#a70aa5816bde60f5511f2308971794881"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
