@@ -1,5 +1,11 @@
 var NAVTREEINDEX6 =
 {
+"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,61,26],
+"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,61,15],
+"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,61,31],
+"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,61,14],
+"stream_8h.html":[11,0,62],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106":[11,0,62,5],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b":[11,0,62,5,2],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125":[11,0,62,5,3],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c":[11,0,62,5,4],
@@ -35,13 +41,14 @@ var NAVTREEINDEX6 =
 "structbuffer.html#a89e90c78766d7752205fc656265fcf6d":[10,0,0,2],
 "structbuffer.html#aa44533c5c02fdb7e3a6a871e15cbc6ff":[10,0,0,1],
 "structcontrol.html":[10,0,1],
-"structcontrol.html#a0007c2838ce6bfcae3b70e79afa47882":[10,0,1,5],
-"structcontrol.html#a7692004aa39ce745bf1adfaa0df538f3":[10,0,1,6],
-"structcontrol.html#a92ce8cd45f48c1ec27c2f7c79ec82a93":[10,0,1,4],
-"structcontrol.html#aa9141611498aca4de42a787f5275ccc9":[10,0,1,1],
-"structcontrol.html#aded6eaccaea7665d8226a8d9caca5278":[10,0,1,3],
-"structcontrol.html#aea2a5224a07931eb7decb7438de18ad7":[10,0,1,2],
-"structcontrol.html#afc1575acdac04527753a78ff0383ee92":[10,0,1,0],
+"structcontrol.html#a0007c2838ce6bfcae3b70e79afa47882":[10,0,1,6],
+"structcontrol.html#a7692004aa39ce745bf1adfaa0df538f3":[10,0,1,7],
+"structcontrol.html#a92ce8cd45f48c1ec27c2f7c79ec82a93":[10,0,1,5],
+"structcontrol.html#aa9141611498aca4de42a787f5275ccc9":[10,0,1,2],
+"structcontrol.html#aded6eaccaea7665d8226a8d9caca5278":[10,0,1,4],
+"structcontrol.html#aea2a5224a07931eb7decb7438de18ad7":[10,0,1,3],
+"structcontrol.html#aed9a36f0e4fedd43932feedf499a15a4":[10,0,1,0],
+"structcontrol.html#afc1575acdac04527753a78ff0383ee92":[10,0,1,1],
 "structdata.html":[10,0,2],
 "structdata.html#a26f2e420b61d6dfdc6422c9d3494f69e":[10,0,2,0],
 "structdata.html#a9557370cbf3e47913eb5e8366574f15e":[10,0,2,1],
@@ -51,30 +58,32 @@ var NAVTREEINDEX6 =
 "structerror__data.html#a3a830f98326d41ac3439452e8d3a6aae":[10,0,3,1],
 "structerror__data.html#a9cbf02e13aa6a4f7d76611ac674d7341":[10,0,3,2],
 "structfilter.html":[10,0,4],
-"structfilter.html#a00baa7796ebf97e59863106d73640a19":[10,0,4,17],
-"structfilter.html#a033a9d50fe013ff96d02fb23d767521d":[10,0,4,19],
-"structfilter.html#a0e58480b42495dee8001219fb2b57968":[10,0,4,6],
-"structfilter.html#a0e7ae9fbfae9ec2bd192c67f0a966633":[10,0,4,14],
-"structfilter.html#a0f722c6917d852102b79e08b806d487d":[10,0,4,5],
-"structfilter.html#a25920211071120caccb1773f36a5048f":[10,0,4,9],
-"structfilter.html#a373d3bc6daf14edc724048bd412caa8e":[10,0,4,2],
-"structfilter.html#a3d3bbf50569618ec2aaaf732be2b939a":[10,0,4,10],
-"structfilter.html#a411f8b027a2391acb338416baee33d71":[10,0,4,4],
-"structfilter.html#a42bfb93f6d5383083c0f5288a43836a4":[10,0,4,8],
-"structfilter.html#a447c7842001ed3fa927244d593ef1d4f":[10,0,4,13],
-"structfilter.html#a576795bfa992c35fddb427543ad5bd59":[10,0,4,3],
-"structfilter.html#a76a94f8c10bd533f2cd367ae43bd87bb":[10,0,4,12],
-"structfilter.html#a78a505bffa0426e75fd31047717d1352":[10,0,4,11],
-"structfilter.html#a7d8760fd7ea20050865cf7acdaa1b7ca":[10,0,4,1],
-"structfilter.html#aac318f767812a647cfbc5185003a73bd":[10,0,4,23],
-"structfilter.html#ab8c65999c3601116155e31cd7d47e232":[10,0,4,15],
-"structfilter.html#ac2f65174639e5113b0a4a597c1d67bb4":[10,0,4,18],
-"structfilter.html#ac387f99d6533daf6511189240eb0846c":[10,0,4,20],
+"structfilter.html#a00baa7796ebf97e59863106d73640a19":[10,0,4,19],
+"structfilter.html#a033a9d50fe013ff96d02fb23d767521d":[10,0,4,21],
+"structfilter.html#a0e58480b42495dee8001219fb2b57968":[10,0,4,8],
+"structfilter.html#a0e7ae9fbfae9ec2bd192c67f0a966633":[10,0,4,16],
+"structfilter.html#a0f722c6917d852102b79e08b806d487d":[10,0,4,7],
+"structfilter.html#a25920211071120caccb1773f36a5048f":[10,0,4,11],
+"structfilter.html#a373d3bc6daf14edc724048bd412caa8e":[10,0,4,3],
+"structfilter.html#a3d3bbf50569618ec2aaaf732be2b939a":[10,0,4,12],
+"structfilter.html#a411f8b027a2391acb338416baee33d71":[10,0,4,6],
+"structfilter.html#a42bfb93f6d5383083c0f5288a43836a4":[10,0,4,10],
+"structfilter.html#a447c7842001ed3fa927244d593ef1d4f":[10,0,4,15],
+"structfilter.html#a576795bfa992c35fddb427543ad5bd59":[10,0,4,5],
+"structfilter.html#a76a94f8c10bd533f2cd367ae43bd87bb":[10,0,4,14],
+"structfilter.html#a78a505bffa0426e75fd31047717d1352":[10,0,4,13],
+"structfilter.html#a7d8760fd7ea20050865cf7acdaa1b7ca":[10,0,4,2],
+"structfilter.html#a926f510d8187d1d62cde60e11f000c7d":[10,0,4,4],
+"structfilter.html#aac318f767812a647cfbc5185003a73bd":[10,0,4,25],
+"structfilter.html#ab8c65999c3601116155e31cd7d47e232":[10,0,4,17],
+"structfilter.html#ac387f99d6533daf6511189240eb0846c":[10,0,4,22],
 "structfilter.html#acd59c2cc491aeaa70daaa087e49a6596":[10,0,4,0],
-"structfilter.html#aea66d542b1b385ea8bccd0c2e54d5a68":[10,0,4,7],
-"structfilter.html#af6ec9143b41642c1b07e90eba876ad92":[10,0,4,21],
-"structfilter.html#af88c144f36d4cd604669eba7f12eec75":[10,0,4,22],
-"structfilter.html#affe704740ff57363fdb29fb7ef558666":[10,0,4,16],
+"structfilter.html#ad5b88e4e7b9e43029cb6b4317d19776c":[10,0,4,20],
+"structfilter.html#aea66d542b1b385ea8bccd0c2e54d5a68":[10,0,4,9],
+"structfilter.html#aebd1411b987e755fede0a644fcc65350":[10,0,4,1],
+"structfilter.html#af6ec9143b41642c1b07e90eba876ad92":[10,0,4,23],
+"structfilter.html#af88c144f36d4cd604669eba7f12eec75":[10,0,4,24],
+"structfilter.html#affe704740ff57363fdb29fb7ef558666":[10,0,4,18],
 "structhandle.html":[10,0,5],
 "structhandle.html#a5ab45bc1d6b1241a2bfde3b297579087":[10,0,5,3],
 "structhandle.html#a767c770296740f81b64b215a2b164e25":[10,0,5,2],
@@ -240,14 +249,5 @@ var NAVTREEINDEX6 =
 "structpw__data__loop__events.html":[10,0,31],
 "structpw__data__loop__events.html#a19c5624deda8fb2d4fd452bf6ba6c3b8":[10,0,31,1],
 "structpw__data__loop__events.html#a5ee1e79472b7ab5aab28d40df7a1db0b":[10,0,31,0],
-"structpw__device__events.html":[10,0,32],
-"structpw__device__events.html#a01a060fea8c0b9d8ccd4eb2aff2848e6":[10,0,32,0],
-"structpw__device__events.html#a75a9ec87b680ae9f45503fbbc1b0fcc9":[10,0,32,1],
-"structpw__device__events.html#adbe2ffa9bd2bcf75f82ce7cfd99ebb29":[10,0,32,2],
-"structpw__device__info.html":[10,0,33],
-"structpw__device__info.html#a05bdd1fb2e89f763b27fe8784cb3e5c2":[10,0,33,1],
-"structpw__device__info.html#a3c53740de36a82a69153911b6777f66e":[10,0,33,0],
-"structpw__device__info.html#a8167e42a1f2bebaddedd6987b9dd39ac":[10,0,33,4],
-"structpw__device__info.html#accce9f7bcbbb1e5142298f18ce03d799":[10,0,33,2],
-"structpw__device__info.html#ad8eb88e166e5527d4d5f418e591274c0":[10,0,33,3]
+"structpw__device__events.html":[10,0,32]
 };
