@@ -2,6 +2,6 @@ var structmemblock =
 [
     [ "link", "structmemblock.html#a66faf89d7710e4bcb353a0ce9e90dede", null ],
     [ "mappings", "structmemblock.html#a204124ca1c489839721b81d7a9210123", null ],
-    [ "maps", "structmemblock.html#a28a7d3a3e9c6b5b1ef201d93ad0ace57", null ],
+    [ "memmaps", "structmemblock.html#af41c0ef0cd3cf472b2a16c478ab81ef1", null ],
     [ "this", "structmemblock.html#a38119a16fff6fd613c41a11b9d7ee1a8", null ]
 ];
\ No newline at end of file
